==> datamule-1.2.8-py3-none-any.whl: datamule/document/mappings/d.py <==
issuer_list_d_dict = {
    'issuer_issuerAddress_street1': 'issuerStreet1',
    'issuer_cik': 'issuerCik', 
    'issuer_issuerAddress_stateOrCountryDescription': 'issuerStateOrCountryDescription',
    'issuer_issuerAddress_zipCode': 'issuerZipCode',
    'issuer_issuerPhoneNumber': 'issuerPhoneNumber',
    'issuer_yearOfInc_value': 'yearOfIncValue',
    'issuer_issuerAddress_stateOrCountry': 'issuerStateOrCountry',
    'issuer_jurisdictionOfInc': 'jurisdictionOfInc',
    'issuer_entityType': 'entityType',
    'issuer_issuerAddress_street2': 'issuerStreet2',
    'issuer_entityName': 'entityName',
    'accession': 'accessionNumber',
    'issuer_edgarPreviousNameList_value': 'edgarPreviousNameListValue',
    'issuer_entityTypeOtherDesc': 'entityTypeOtherDesc',
    'issuer_yearOfInc_yetToBeFormed': 'yearOfIncYetToBeFormed',
    'issuer_yearOfInc_withinFiveYears': 'yearOfIncWithinFiveYears',
    'issuer_issuerPreviousNameList_value': 'issuerPreviousNameListValue',
    'issuer_issuerAddress_city': 'issuerCity'
}

metadata_d_dict = {
"testOrLive" : "testOrLive",
"schemaVersion" : "schemaVersion",
"accession" : "accession",
"submissionType" : "submissionType",
}
offering_data_d_dict = {
    'salesCompensationList_recipient': 'salesCompensationRecipient',
    'useOfProceeds_clarificationOfResponse': 'useOfProceedsClarification',
    'industryGroup_investmentFundInfo_investmentFundType': 'investmentFundType',
    'typeOfFiling_newOrAmendment_isAmendment': 'isAmendment',
    'salesCompensationList_recipient_recipientAddress_stateOrCountryDescription': 'recipientStateOrCountryDescription',
    'signatureBlock_signature_signatureName': 'signatureName',
    'federalExemptionsExclusions_item': 'federalExemptionsItem',
    'salesCommissionsFindersFees_findersFees_isEstimate': 'findersFeesIsEstimate',
    'salesCommissionsFindersFees_salesCommissions_dollarAmount': 'salesCommissionsDollarAmount',
    'salesCompensationList_recipient_recipientName': 'recipientName',
    'salesCommissionsFindersFees_salesCommissions_isEstimate': 'salesCommissionsIsEstimate',
    'offeringSalesAmounts_totalRemaining': 'totalRemaining',
    'salesCommissionsFindersFees_clarificationOfResponse': 'salesCommissionsClarification',
    'salesCompensationList_recipient_statesOfSolicitationList_value': 'recipientStatesOfSolicitationValue',
    'investors_numberNonAccreditedInvestors': 'numberNonAccreditedInvestors',
    'typesOfSecuritiesOffered_isTenantInCommonType': 'isTenantInCommonType',
    'businessCombinationTransaction_isBusinessCombinationTransaction': 'isBusinessCombinationTransaction',
    'typesOfSecuritiesOffered_isSecurityToBeAcquiredType': 'isSecurityToBeAcquiredType',
    'issuerSize_aggregateNetAssetValueRange': 'aggregateNetAssetValueRange',
    'typesOfSecuritiesOffered_isPooledInvestmentFundType': 'isPooledInvestmentFundType',
    'offeringSalesAmounts_clarificationOfResponse': 'offeringSalesAmountsClarification',
    'signatureBlock_signature_nameOfSigner': 'nameOfSigner',
    'industryGroup_investmentFundInfo_is40Act': 'is40Act',
    'salesCompensationList_recipient_recipientAddress_city': 'recipientCity',
    'typeOfFiling_dateOfFirstSale_yetToOccur': 'dateOfFirstSaleYetToOccur',
    'signatureBlock_signature': 'signature',
    'salesCompensationList_recipient_foreignSolicitation': 'recipientForeignSolicitation',
    'businessCombinationTransaction_clarificationOfResponse': 'businessCombinationClarification',
    'salesCompensationList_recipient_associatedBDName': 'recipientAssociatedBDName',
    'salesCompensationList_recipient_statesOfSolicitationList_state': 'recipientStatesOfSolicitationState',
    'typeOfFiling_dateOfFirstSale_value': 'dateOfFirstSaleValue',
    'signatureBlock_signature_signatureTitle': 'signatureTitle',
    'signatureBlock_signature_issuerName': 'signatureIssuerName',
    'durationOfOffering_moreThanOneYear': 'durationOfferingMoreThanOneYear',
    'offeringSalesAmounts_totalAmountSold': 'totalAmountSold',
    'signatureBlock_signature_signatureDate': 'signatureDate',
    'issuerSize_revenueRange': 'revenueRange',
    'typesOfSecuritiesOffered_isOptionToAcquireType': 'isOptionToAcquireType',
    'signatureBlock_authorizedRepresentative': 'authorizedRepresentative',
    'salesCompensationList_recipient_recipientAddress_street2': 'recipientStreet2',
    'useOfProceeds_grossProceedsUsed_isEstimate': 'grossProceedsUsedIsEstimate',
    'salesCommissionsFindersFees_findersFees_dollarAmount': 'findersFeesDollarAmount',
    'typesOfSecuritiesOffered_isEquityType': 'isEquityType',
    'typesOfSecuritiesOffered_descriptionOfOtherType': 'descriptionOfOtherType',
    'salesCompensationList_recipient_recipientAddress_street1': 'recipientStreet1',
    'minimumInvestmentAccepted': 'minimumInvestmentAccepted',
    'typesOfSecuritiesOffered_isOtherType': 'isOtherType',
    'salesCompensationList_recipient_recipientCRDNumber': 'recipientCRDNumber',
    'typesOfSecuritiesOffered_isDebtType': 'isDebtType',
    'accession': 'accessionNumber',
    'investors_totalNumberAlreadyInvested': 'totalNumberAlreadyInvested',
    'typesOfSecuritiesOffered_isMineralPropertyType': 'isMineralPropertyType',
    'industryGroup_industryGroupType': 'industryGroupType',
    'salesCompensationList_recipient_statesOfSolicitationList_description': 'recipientStatesOfSolicitationDescription',
    'salesCompensationList_recipient_associatedBDCRDNumber': 'recipientAssociatedBDCRDNumber',
    'useOfProceeds_grossProceedsUsed_dollarAmount': 'grossProceedsUsedDollarAmount',
    'investors_hasNonAccreditedInvestors': 'hasNonAccreditedInvestors',
    'salesCompensationList_recipient_recipientAddress_zipCode': 'recipientZipCode',
    'offeringSalesAmounts_totalOfferingAmount': 'totalOfferingAmount',
    'salesCompensationList_recipient_recipientAddress_stateOrCountry': 'recipientStateOrCountry'
}
primary_issuer_d_dict = {
    'yearOfInc_withinFiveYears': 'yearOfIncWithinFiveYears',
    'entityTypeOtherDesc': 'entityTypeOtherDesc',
    'jurisdictionOfInc': 'jurisdictionOfInc',
    'issuerAddress_street1': 'issuerStreet1',
    'issuerAddress_zipCode': 'issuerZipCode',
    'issuerPreviousNameList_previousName': 'issuerPreviousName',
    'entityType': 'entityType',
    'issuerPreviousNameList_value': 'issuerPreviousNameListValue',
    'issuerPhoneNumber': 'issuerPhoneNumber',
    'yearOfInc_value': 'yearOfIncValue',
    'yearOfInc_yetToBeFormed': 'yearOfIncYetToBeFormed',
    'edgarPreviousNameList_previousName': 'edgarPreviousName',
    'edgarPreviousNameList_value': 'edgarPreviousNameListValue',
    'issuerAddress_stateOrCountry': 'issuerStateOrCountry',
    'entityName': 'entityName',
    'accession': 'accessionNumber',
    'issuerAddress_street2': 'issuerStreet2',
    'issuerAddress_city': 'issuerCity',
    'issuerAddress_stateOrCountryDescription': 'issuerStateOrCountryDescription',
    'cik': 'cik',
    'yearOfInc_overFiveYears': 'yearOfIncOverFiveYears'
}

related_persons_d_dict = {
    'relatedPersonInfo_relatedPersonAddress_stateOrCountry': 'relatedPersonStateOrCountry',
    'relatedPersonInfo_relatedPersonRelationshipList_relationship': 'relatedPersonRelationship',
    'relatedPersonInfo_relationshipClarification': 'relationshipClarification',
    'relatedPersonInfo_relatedPersonName_lastName': 'relatedPersonLastName',
    'accession': 'accessionNumber',
    'relatedPersonInfo_relatedPersonName_middleName': 'relatedPersonMiddleName',
    'relatedPersonInfo_relatedPersonAddress_zipCode': 'relatedPersonZipCode',
    'relatedPersonInfo_relatedPersonAddress_city': 'relatedPersonCity',
    'relatedPersonInfo_relatedPersonAddress_street1': 'relatedPersonStreet1',
    'relatedPersonInfo_relatedPersonAddress_stateOrCountryDescription': 'relatedPersonStateOrCountryDescription',
    'relatedPersonInfo_relatedPersonName_firstName': 'relatedPersonFirstName',
    'relatedPersonInfo_relatedPersonAddress_street2': 'relatedPersonStreet2'
}

==> datamule-1.5.2-py3-none-any.whl: datamule/document/mappings/d.py <==
issuer_list_d_dict = {
    'issuer_issuerAddress_street1': 'issuerStreet1',
    'issuer_cik': 'issuerCik', 
    'issuer_issuerAddress_stateOrCountryDescription': 'issuerStateOrCountryDescription',
    'issuer_issuerAddress_zipCode': 'issuerZipCode',
    'issuer_issuerPhoneNumber': 'issuerPhoneNumber',
    'issuer_yearOfInc_value': 'yearOfIncValue',
    'issuer_issuerAddress_stateOrCountry': 'issuerStateOrCountry',
    'issuer_jurisdictionOfInc': 'jurisdictionOfInc',
    'issuer_entityType': 'entityType',
    'issuer_issuerAddress_street2': 'issuerStreet2',
    'issuer_entityName': 'entityName',
    'accession': 'accession',
    'issuer_edgarPreviousNameList_value': 'edgarPreviousNameListValue',
    'issuer_entityTypeOtherDesc': 'entityTypeOtherDesc',
    'issuer_yearOfInc_yetToBeFormed': 'yearOfIncYetToBeFormed',
    'issuer_yearOfInc_withinFiveYears': 'yearOfIncWithinFiveYears',
    'issuer_issuerPreviousNameList_value': 'issuerPreviousNameListValue',
    'issuer_issuerAddress_city': 'issuerCity'
}

metadata_d_dict = {
"testOrLive" : "testOrLive",
"schemaVersion" : "schemaVersion",
"accession" : "accession",
"submissionType" : "submissionType",
}
offering_data_d_dict = {
    'salesCompensationList_recipient_foreignSolicitation': 'foreignSolicitation',
    'typeOfFiling_dateOfFirstSale_yetToOccur': 'dateOfFirstSaleYetToOccur',
    'industryGroup_investmentFundInfo_is40Act': 'is40Act',
    'salesCommissionsFindersFees_findersFees_dollarAmount': 'findersFeesAmount',
    'offeringSalesAmounts_totalRemaining': 'totalRemaining',
    'issuerSize_aggregateNetAssetValueRange': 'aggregateNetAssetValueRange',
    'typesOfSecuritiesOffered_isSecurityToBeAcquiredType': 'isSecurityToBeAcquiredType',
    'salesCompensationList_recipient_recipientAddress_stateOrCountryDescription': 'recipientStateOrCountryDescription',
    'typesOfSecuritiesOffered_isEquityType': 'isEquityType',
    'investors_totalNumberAlreadyInvested': 'totalNumberAlreadyInvested',
    'minimumInvestmentAccepted': 'minimumInvestmentAccepted',
    'salesCompensationList_recipient_associatedBDName': 'associatedBDName',
    'salesCompensationList_recipient_statesOfSolicitationList_state': 'statesOfSolicitationState',
    'businessCombinationTransaction_isBusinessCombinationTransaction': 'isBusinessCombinationTransaction',
    'useOfProceeds_grossProceedsUsed_isEstimate': 'grossProceedsUsedIsEstimate',
    'federalExemptionsExclusions_item': 'federalExemptionsExclusionsItem',
    'useOfProceeds_grossProceedsUsed_dollarAmount': 'grossProceedsUsedAmount',
    'industryGroup_industryGroupType': 'industryGroupType',
    'signatureBlock_signature_nameOfSigner': 'nameOfSigner',
    'signatureBlock_signature_signatureDate': 'signatureDate',
    'salesCommissionsFindersFees_salesCommissions_isEstimate': 'salesCommissionsIsEstimate',
    'typesOfSecuritiesOffered_isOtherType': 'isOtherType',
    'salesCompensationList_recipient_associatedBDCRDNumber': 'associatedBDCRDNumber',
    'salesCompensationList_recipient_recipientAddress_stateOrCountry': 'recipientStateOrCountry',
    'typesOfSecuritiesOffered_descriptionOfOtherType': 'descriptionOfOtherType',
    'salesCommissionsFindersFees_salesCommissions_dollarAmount': 'salesCommissionsAmount',
    'useOfProceeds_clarificationOfResponse': 'useOfProceedsClarification',
    'accession': 'accession',
    'typesOfSecuritiesOffered_isPooledInvestmentFundType': 'isPooledInvestmentFundType',
    'salesCompensationList_recipient_statesOfSolicitationList_value': 'statesOfSolicitationValue',
    'signatureBlock_signature_signatureName': 'signatureName',
    'typeOfFiling_newOrAmendment_isAmendment': 'isAmendment',
    'issuerSize_revenueRange': 'revenueRange',
    'salesCommissionsFindersFees_clarificationOfResponse': 'salesCommissionsFindersFeesClarification',
    'salesCompensationList_recipient_recipientAddress_zipCode': 'recipientZipCode',
    'salesCompensationList_recipient_recipientAddress_city': 'recipientCity',
    'typesOfSecuritiesOffered_isOptionToAcquireType': 'isOptionToAcquireType',
    'businessCombinationTransaction_clarificationOfResponse': 'businessCombinationClarification',
    'typesOfSecuritiesOffered_isTenantInCommonType': 'isTenantInCommonType',
    'salesCompensationList_recipient_statesOfSolicitationList_description': 'statesOfSolicitationDescription',
    'offeringSalesAmounts_totalOfferingAmount': 'totalOfferingAmount',
    'investors_numberNonAccreditedInvestors': 'numberNonAccreditedInvestors',
    'signatureBlock_authorizedRepresentative': 'authorizedRepresentative',
    'signatureBlock_signature_issuerName': 'issuerName',
    'salesCompensationList_recipient_recipientAddress_street2': 'recipientStreet2',
    'typesOfSecuritiesOffered_isDebtType': 'isDebtType',
    'salesCompensationList_recipient_recipientAddress_street1': 'recipientStreet1',
    'signatureBlock_signature_signatureTitle': 'signatureTitle',
    'industryGroup_investmentFundInfo_investmentFundType': 'investmentFundType',
    'salesCommissionsFindersFees_findersFees_isEstimate': 'findersFeesIsEstimate',
    'typeOfFiling_dateOfFirstSale_value': 'dateOfFirstSaleValue',
    'offeringSalesAmounts_totalAmountSold': 'totalAmountSold',
    'offeringSalesAmounts_clarificationOfResponse': 'offeringSalesAmountsClarification',
    'investors_hasNonAccreditedInvestors': 'hasNonAccreditedInvestors',
    'salesCompensationList_recipient_recipientCRDNumber': 'recipientCRDNumber',
    'typesOfSecuritiesOffered_isMineralPropertyType': 'isMineralPropertyType',
    'salesCompensationList_recipient_recipientName': 'recipientName',
    'durationOfOffering_moreThanOneYear': 'moreThanOneYear'
}
primary_issuer_d_dict = {
    'yearOfInc_withinFiveYears': 'yearOfIncWithinFiveYears',
    'entityTypeOtherDesc': 'entityTypeOtherDesc',
    'jurisdictionOfInc': 'jurisdictionOfInc',
    'issuerAddress_street1': 'issuerStreet1',
    'issuerAddress_zipCode': 'issuerZipCode',
    'issuerPreviousNameList_previousName': 'issuerPreviousName',
    'entityType': 'entityType',
    'issuerPreviousNameList_value': 'issuerPreviousNameListValue',
    'issuerPhoneNumber': 'issuerPhoneNumber',
    'yearOfInc_value': 'yearOfIncValue',
    'yearOfInc_yetToBeFormed': 'yearOfIncYetToBeFormed',
    'edgarPreviousNameList_previousName': 'edgarPreviousName',
    'edgarPreviousNameList_value': 'edgarPreviousNameListValue',
    'issuerAddress_stateOrCountry': 'issuerStateOrCountry',
    'entityName': 'entityName',
    'accession': 'accession',
    'issuerAddress_street2': 'issuerStreet2',
    'issuerAddress_city': 'issuerCity',
    'issuerAddress_stateOrCountryDescription': 'issuerStateOrCountryDescription',
    'cik': 'cik',
    'yearOfInc_overFiveYears': 'yearOfIncOverFiveYears'
}

related_persons_d_dict = {
    'relatedPersonInfo_relatedPersonAddress_stateOrCountry': 'relatedPersonStateOrCountry',
    'relatedPersonInfo_relatedPersonRelationshipList_relationship': 'relatedPersonRelationship',
    'relatedPersonInfo_relationshipClarification': 'relationshipClarification',
    'relatedPersonInfo_relatedPersonName_lastName': 'relatedPersonLastName',
    'accession': 'accession',
    'relatedPersonInfo_relatedPersonName_middleName': 'relatedPersonMiddleName',
    'relatedPersonInfo_relatedPersonAddress_zipCode': 'relatedPersonZipCode',
    'relatedPersonInfo_relatedPersonAddress_city': 'relatedPersonCity',
    'relatedPersonInfo_relatedPersonAddress_street1': 'relatedPersonStreet1',
    'relatedPersonInfo_relatedPersonAddress_stateOrCountryDescription': 'relatedPersonStateOrCountryDescription',
    'relatedPersonInfo_relatedPersonName_firstName': 'relatedPersonFirstName',
    'relatedPersonInfo_relatedPersonAddress_street2': 'relatedPersonStreet2'
}
